# gmagpie

![Version: 0.1.0](https://img.shields.io/badge/Version-0.1.0-informational?style=flat-square) ![Type: application](https://img.shields.io/badge/Type-application-informational?style=flat-square) ![AppVersion: 0.1.0](https://img.shields.io/badge/AppVersion-0.1.0-informational?style=flat-square)

A Helm chart for GMagpie

## Values

| Key | Type | Default | Description |
|-----|------|---------|-------------|
| apiserver.affinity | object | `{}` | gmagpie-apiserver affinity |
| apiserver.apiServer.port | int | `3000` | gmagpie-apiserver http port |
| apiserver.database.log.colorful | bool | `true` | Set gorm log style |
| apiserver.database.log.slowThreshold | string | `"100ms"` | Slow SQL threshold |
| apiserver.database.log.stdout | bool | `true` | Set gorm log output level |
| apiserver.debug | bool | `false` | config for local dev env |
| apiserver.fixturePath | string | `"../../fixtures"` | storing static files（sql、image、yaml） |
| apiserver.hostAliases | list | `[]` | gmagpie-apiserver hostAliases |
| apiserver.hostNetwork | bool | `false` | "true" means using hostNetwork. "false" means normal network |
| apiserver.image.pullPolicy | string | `"IfNotPresent"` | Pull policy of image |
| apiserver.image.pullSecrets | list | `[]` | Pull secrets of image |
| apiserver.image.registry | string | `"release.daocloud.io"` | gmagpie-apiserver image registry |
| apiserver.image.repository | string | `"gmagpie/gmagpie-apiserver"` | image of the gmagpie-apiserver |
| apiserver.image.tag | string | `""` | the image tag whose default is the chart appVersion |
| apiserver.labels.app | string | `"gmagpie-apiserver"` | gmagpie-apiserver deployment app name |
| apiserver.log.level | string | `"warn"` | Set the gmagpie apiserver log level |
| apiserver.nodeSelector | object | `{}` | gmagpie-apiserver nodeSelector |
| apiserver.podAnnotations | object | `{"prometheus.io/path":"/metrics","prometheus.io/port":"81","prometheus.io/scrape":"true"}` | Add gmagpie apiserver pod annotations |
| apiserver.podLabels | object | `{}` |  |
| apiserver.replicaCount | int | `2` | target replicas |
| apiserver.resources.limits.cpu | string | `"1024m"` |  |
| apiserver.resources.limits.memory | string | `"2048Mi"` |  |
| apiserver.resources.requests.cpu | string | `"10m"` |  |
| apiserver.resources.requests.memory | string | `"64Mi"` |  |
| apiserver.service.annotations | object | `{}` | Annotations for gmagpie apiServer service |
| apiserver.service.clusterIP | string | `""` | Keycloak service clusterIP IP |
| apiserver.service.externalTrafficPolicy | string | `"Cluster"` | Enable client source IP preservation. ref https://kubernetes.io/docs/tasks/access-application-cluster/create-external-load-balancer/#preserving-the-client-source-ip |
| apiserver.service.loadBalancerIP | string | `""` | loadBalancerIP for the SuiteCRM Service (optional, cloud specific). ref: https://kubernetes.io/docs/user-guide/services/#type-loadbalancer |
| apiserver.service.loadBalancerSourceRanges | list | `[]` | Address that are allowed when service is LoadBalancer. https://kubernetes.io/docs/tasks/access-application-cluster/configure-cloud-provider-firewall/#restrict-access-for-loadbalancer-service |
| apiserver.service.nodePorts.grpc | string | `"30031"` | gmagpie-apiserver grpc port |
| apiserver.service.nodePorts.http | string | `"30030"` | gmagpie-apiserver http port |
| apiserver.service.port | int | `80` | Service HTTP port |
| apiserver.service.type | string | `"ClusterIP"` | Kubernetes service type |
| apiserver.tolerations | list | `[]` | gmagpie-apiserver tolerations |
| busybox.image.pullPolicy | string | `"IfNotPresent"` | Pull policy of image |
| busybox.image.pullSecrets | list | `[]` | Pull secrets of image |
| busybox.image.registry | string | `"release.daocloud.io"` | busybox image registry |
| busybox.image.repository | string | `"ghippo/busybox"` | Image of the daocloud-theme FIXME: |
| busybox.image.tag | string | `"1.28.4"` | the image tag whose default is the 1.28.4 |
| controllermanager.affinity | object | `{}` | controllermanager affinity |
| controllermanager.image.pullPolicy | string | `"IfNotPresent"` | Pull policy of image |
| controllermanager.image.pullSecrets | list | `[]` | Pull secrets of image |
| controllermanager.image.registry | string | `"release.daocloud.io"` | controllermanager image registry |
| controllermanager.image.repository | string | `"gmagpie/gmagpie-apiserver"` | image of the controller manager |
| controllermanager.image.tag | string | `""` | the image tag whose default is the chart appVersion |
| controllermanager.labels.app | string | `"gmagpie-controller-manager"` | controllermanager deployment app name |
| controllermanager.nodeSelector | object | `{}` | controllermanager nodeSelector |
| controllermanager.podAnnotations | object | `{}` | Add controllermanager pod annotations |
| controllermanager.podLabels | object | `{}` |  |
| controllermanager.replicaCount | int | `2` | target replicas |
| controllermanager.resources.limits.cpu | string | `"1024m"` |  |
| controllermanager.resources.limits.memory | string | `"1024Mi"` |  |
| controllermanager.resources.requests.cpu | string | `"5m"` |  |
| controllermanager.resources.requests.memory | string | `"128Mi"` |  |
| controllermanager.tolerations | list | `[]` | controllermanager tolerations |
| global.database.apiserver.dbname | string | `"gmagpie"` | database name used by gmagpie-apiserver |
| global.database.apiserver.password | string | `"changeme"` | database password used by gmagpie-apiserver |
| global.database.apiserver.user | string | `"gmagpie"` | database username used by gmagpie-apiserver |
| global.database.builtIn | bool | `false` | If builtIn is true, the built-in database will be used |
| global.database.host | string | `"gmagpie-mysql.gmagpie-system.svc.cluster.local"` | database host, domain name or IP address |
| global.database.port | int | `3306` | database port |
| global.database.type | string | `"mysql"` | Database type used by gmagpie（mysql | pg） |
| global.enabledComponents.developers | bool | `true` | If developers is true, enable the developers page |
| global.enabledComponents.docUrl | string | `""` | anakin doc url config |
| global.imagePullSecrets | list | `[]` | Global registry secret names as an array |
| global.imageRegistry | string | `"release.daocloud.io"` | Global image registry |
| global.injectIstioSidecar | bool | `true` | Global inject istio sidecar |
| mysql.image.pullPolicy | string | `"IfNotPresent"` | Pull policy of image |
| mysql.image.pullSecrets | list | `[]` | Pull secrets of image |
| mysql.image.registry | string | `"release.daocloud.io"` | mysql image registry |
| mysql.image.repository | string | `"ghippo/mysql"` | image of the mysql FIXME: |
| mysql.image.tag | string | `"5.7"` | the image tag whose default is the 5.7 |
| tailingSidecar.image.pullPolicy | string | `"IfNotPresent"` | Pull policy of image |
| tailingSidecar.image.pullSecrets | list | `[]` | Pull secrets of image |
| tailingSidecar.image.registry | string | `"release.daocloud.io"` | tailingSidecar image registry |
| tailingSidecar.image.repository | string | `"ghippo/busybox"` | tailingSidecar image registry FIXME: |
| tailingSidecar.image.tag | string | `"1.28.4"` | the image tag whose default is the 1.24.3 |
| ui.image.pullPolicy | string | `"IfNotPresent"` | Pull policy of image |
| ui.image.pullSecrets | list | `[]` | Pull secrets of image |
| ui.image.registry | string | `"release.daocloud.io"` | ui image registry |
| ui.image.repository | string | `"gmagpie/gmagpie-ui"` | Image of the apiserver |
| ui.image.tag | string | `"v0.8.0"` | the image tag whose default is the latest |
| ui.labels.app | string | `"gmagpie-ui"` | gmagpie-ui deployment app name |
| ui.podLabels | object | `{}` |  |
| ui.replicaCount | int | `2` | Target replicas |
| ui.resources.limits.cpu | string | `"500m"` |  |
| ui.resources.limits.memory | string | `"1024Mi"` |  |
| ui.resources.requests.cpu | string | `"1m"` |  |
| ui.resources.requests.memory | string | `"16Mi"` |  |
| ui.service.nodePorts | object | `{"http":"30089"}` | Specify the nodePort(s) value(s) for the LoadBalancer and NodePort service types. ref: https://kubernetes.io/docs/concepts/services-networking/service/#type-nodeport |
| ui.service.nodePorts.http | string | `"30089"` | ui http nodePort |
| ui.service.port | int | `80` | Service HTTP port |
| ui.service.targetPort.http | string | `"http"` | define ui targetPort name |
| ui.service.type | string | `"ClusterIP"` | Service type |

----------------------------------------------
Autogenerated from chart metadata using [helm-docs v1.11.0](https://github.com/norwoodj/helm-docs/releases/v1.11.0)
