{{/* vim: set filetype=mustache: */}}
{{/*
Return the proper image name
{{ include "common.images.image" ( dict "imageRoot" .Values.path.to.the.image "global" $) }}
*/}}
{{- define "common.images.image" }}
{{- $registryName := .imageRoot.registry }}
{{- $repositoryName := .imageRoot.repository }}
{{- $tag := (default .defaultTag .imageRoot.tag) | toString }}
{{- if .global }}
  {{- if .global.imageRegistry }}
  {{- $registryName = .global.imageRegistry }}
  {{- end }}
{{- end }}
{{- printf "%s/%s:%s" $registryName $repositoryName (default "latest" $tag) }}
{{- end }}

{{/*
Return the proper Docker Image Registry Secret Names (deprecated: use common.images.renderPullSecrets instead)
{{ include "common.images.pullSecrets" ( dict "images" (list .Values.path.to.the.image1, .Values.path.to.the.image2) "global" .Values.global) }}
*/}}
{{- define "common.images.pullSecrets" -}}
  {{- $pullSecrets := list }}

  {{- if .global }}
    {{- range .global.imagePullSecrets }}
      {{- $pullSecrets = append $pullSecrets . }}
    {{- end }}
  {{- end }}

  {{- range .images }}
    {{- range .pullSecrets }}
      {{- $pullSecrets = append $pullSecrets . }}
    {{- end }}
  {{- end }}

  {{- if (not (empty $pullSecrets)) }}
imagePullSecrets:
    {{- range $pullSecrets }}
  - name: {{ . }}
    {{- end }}
  {{- end }}
{{- end -}}

{{/* vim: set filetype=mustache: */}}
{{/*
Returns the sidecar label
{{ include "common.sidecar.istio" ( dict "podLabels" .Values.path.to.the.podLabels "global" $) }}
*/}}
{{- define "common.sidecar.istio" }}
{{- $labelKey := "sidecar.istio.io/inject" }}
{{- $labelValue := .global.injectIstioSidecar | quote }}
{{- $match := false }}
  {{- range $key, $value := .podLabels }}
    {{- if $key }}
      {{- $match = true }}
    {{- end }}
  {{- end }}
{{- if not $match }}
  {{- printf "%s: %s" $labelKey $labelValue }}
{{- end }}
{{- end }}
